@@ -53,7 +53,7 @@ void DavItemsFetchJob::start()
     }
 
     const QDomDocument report = protocol->itemsReportQuery(d->mUrls)->buildQuery();
-    KIO::DavJob *job = DavManager::self()->createReportJob(d->mCollectionUrl.url(), report, QStringLiteral("0"));
+    KIO::DavJob *job = DavManager::self()->createReportJob(d->mCollectionUrl.url(), report.toString(), QStringLiteral("0"));
     job->addMetaData(QStringLiteral("PropagateHttpHeader"), QStringLiteral("true"));
     connect(job, &KIO::DavJob::result, this, [d](KJob *job) {
         d->davJobFinished(job);
@@ -65,7 +65,7 @@ DavItem::List DavItemsFetchJob::items() const
     Q_D(const DavItemsFetchJob);
     DavItem::List values;
     values.reserve(d->mItems.size());
-    for (const auto &value : qAsConst(d->mItems)) {
+    for (const auto &value : std::as_const(d->mItems)) {
         values << value;
     }
     return values;
@@ -97,7 +97,8 @@ void DavItemsFetchJobPrivate::davJobFinished(KJob *job)
 
     const DavMultigetProtocol *protocol = static_cast<const DavMultigetProtocol *>(DavManager::davProtocol(mCollectionUrl.protocol()));
 
-    const QDomDocument document = davJob->response();
+    QDomDocument document;
+    document.setContent(davJob->responseData(), true);
     const QDomElement documentElement = document.documentElement();
 
     QDomElement responseElement = Utils::firstChildElementNS(documentElement, QStringLiteral("DAV:"), QStringLiteral("response"));
